@@ -47,7 +47,9 @@ class HttpResponse(HttpRequest):
             port=None,
             key_file=None,
             cert_file=None,
-            timeout=None):
+            read_timeout=None,
+            connect_timeout=None,
+            verify=None):
         HttpRequest.__init__(
             self,
             host=host,
@@ -61,7 +63,9 @@ class HttpResponse(HttpRequest):
         self.__cert_file = cert_file
         self.__port = port
         self.__connection = None
-        self._timeout = timeout
+        self.__read_timeout = read_timeout
+        self.__connect_timeout = connect_timeout
+        self.__verify = verify
         self.set_body(content)
 
     def set_ssl_enable(self, enable):
@@ -88,6 +92,11 @@ class HttpResponse(HttpRequest):
             response.status_code, status_codes._codes.get(response.status_code)[0].upper())
         logger.debug(response_base + self.prepare_http_debug(response, '<'))
 
+    def get_verify_value(self):
+        if self.__verify is not None:
+            return self.__verify
+        return os.environ.get('ALIBABA_CLOUD_CA_BUNDLE', True)
+
     def get_response_object(self):
         with Session() as s:
             current_protocol = 'https://' if self.get_ssl_enabled() else 'http://'
@@ -112,12 +121,10 @@ class HttpResponse(HttpRequest):
                 "http": proxy_http,
                 "https": proxy_https,
             }
-            # ignore the warning-InsecureRequestWarning
-            urllib3.disable_warnings()
 
             response = s.send(prepped, proxies=proxies,
-                              timeout=(DEFAULT_CONNECT_TIMEOUT, self._timeout),
-                              allow_redirects=False, verify=None, cert=None)
+                              timeout=(self.__connect_timeout, self.__read_timeout),
+                              allow_redirects=False, verify=self.get_verify_value(), cert=None)
 
             http_debug = os.environ.get('DEBUG')
 
